@@ -3,7 +3,7 @@ from __future__ import annotations
 from collections import OrderedDict
 from typing import Any, Dict, Iterable, Iterator, Mapping, Optional, Type, TypeVar
 
-__version__ = "2.2.3"
+__version__ = "2.2.5"
 
 _K = TypeVar("_K")
 _V = TypeVar("_V")
@@ -11,8 +11,10 @@ _V = TypeVar("_V")
 
 class immutabledict(Mapping[_K, _V]):
     """
-    An immutable wrapper around dictionaries that implements the complete :py:class:`collections.Mapping`
-    interface. It can be used as a drop-in replacement for dictionaries where immutability is desired.
+    An immutable wrapper around dictionaries that implements
+    the complete :py:class:`collections.Mapping` interface.
+    It can be used as a drop-in replacement for dictionaries
+    where immutability is desired.
     """
 
     dict_cls: Type[Dict[Any, Any]] = dict
@@ -21,7 +23,7 @@ class immutabledict(Mapping[_K, _V]):
     def fromkeys(
         cls, seq: Iterable[_K], value: Optional[_V] = None
     ) -> "immutabledict[_K, _V]":
-        return cls(dict.fromkeys(seq, value))
+        return cls(cls.dict_cls.fromkeys(seq, value))
 
     def __init__(self, *args: Any, **kwargs: Any) -> None:
         self._dict = self.dict_cls(*args, **kwargs)
